@@ -10,8 +10,28 @@
 #
 #
 "bor" <-
-function(S=35,T=25,P=0){
-	bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
-	attr(bor,"unit") <- "mol/kg"
-	return(bor)
+function(S=35, b="l10"){  #two formulations possible Lee et al., (2010) : "l10" or Uppstrom (1974) : "u74"
+
+n <- max(c(length(S), length(b)))
+if(length(S)!=n){ S <- rep(S[1],n)}
+if(length(b)!=n){ b <- rep(b[1],n)}
+bor <- rep(NA, n)
+method <- rep(NA, n)
+
+for(i in 1:n){
+if(b[i]=="l10"){
+bor[i] <- 0.1336*S[i] #boron in mg/kg
+method[i] <- "Lee et al. (2010)"
+}
+if(b[i]=="u74"){
+bor[i] <- 0.1284*S[i] #boron in mg/kg
+method[i] <- "Uppstrom (1974)"
+}
+}
+# conversion from mg/kg to mol/kg
+bor <- bor*10^(-3)/10.811
+attr(bor,"unit") <- "mol/kg"
+attr(bor, "method") <- method
+
+return(bor)
 }
